@@ -15,7 +15,7 @@ def listreqs(path):
             f.write('\n')
 
 def listreqs_shell():
-    subprocess.call(['sh', './listreqs.sh'])
+    subprocess.call(['sh', 'listreqs.sh'])
 
 if __name__ == "__main__":
     listreqs_shell()
\ No newline at end of file
